# Copyright 2021 (c) Anna Schumaker.
import db
import sqlite3
import unittest
from gi.repository import GObject


class TestPlaylistState(unittest.TestCase):
    def test_init(self):
        state = db.state.Table.insert()

        self.assertIsInstance(state, GObject.GObject)
        self.assertIsNotNone(state._plstateid)
        self.assertEqual(state.rowid, state._plstateid)

    def test_random(self):
        state = db.state.Table.insert()
        self.assertFalse(state._random)
        self.assertFalse(state.get_property("random"))

        state.random = True
        self.assertTrue(state._random)

    def test_loop(self):
        state = db.state.Table.insert()
        self.assertFalse(state._loop)
        self.assertFalse(state.get_property("loop"))

        state.loop = True
        self.assertTrue(state._loop)

    def test_current(self):
        state = db.state.Table.insert()
        self.assertEqual(state._current, -1)
        self.assertEqual(state.current, -1)

        state.current = 3
        self.assertEqual(state._current, 3)

    def test_sort(self):
        state = db.state.Table.insert()
        self.assertEqual(state._sort, ",".join(db.state.DefaultSort))
        self.assertEqual(state.sort, db.state.DefaultSort)

        state.sort = [ "test", "sort" ]
        self.assertEqual(state._sort, "test,sort" )


class TestPlaylistStateTable(unittest.TestCase):
    def setUp(self):
        db.reset()

    def test_init(self):
        table = db.state.PlaylistStateTable()
        self.assertIsInstance(table, db.table.Table)
        self.assertEqual(table.table, "playlist_states")

        self.assertIsInstance(db.state.Table, db.state.PlaylistStateTable)
        db.sql.execute("SELECT plstateid,random,loop,current,sort "
                       "FROM playlist_states")

    def test_default_sort(self):
        self.assertEqual(db.state.DefaultSort[0], "artists.sort ASC")
        self.assertEqual(db.state.DefaultSort[1], "albums.sort ASC")
        self.assertEqual(db.state.DefaultSort[2], "years.year ASC")
        self.assertEqual(db.state.DefaultSort[3], "discs.number ASC")
        self.assertEqual(db.state.DefaultSort[4], "tracks.number ASC")

    def test_insert(self):
        table = db.state.PlaylistStateTable()
        state = table.insert()

        self.assertFalse(state.random)
        self.assertFalse(state.loop)
        self.assertEqual(state.current, -1)
        self.assertEqual(state.sort, db.state.DefaultSort)

    def test_lookup(self):
        with self.assertRaises(NotImplementedError):
            db.state.Table.lookup()
