# Copyright 2021 (c) Anna Schumaker.
import datetime
import db
import pathlib
import scanner
import unittest

test_album = pathlib.Path("./data/Test Album")
test_track = test_album / "01 - Test Track.ogg"

class TestScanner(unittest.TestCase):
    def tearDown(self):
        scanner.Queue.tasks_finished()

    def test_scanner_init(self):
        self.assertIsInstance(scanner.Queue, scanner.queue.TaskQueue)

    def test_scanner_import_track(self):
        lib = db.library.Table.find(test_album)
        scanner.import_track(lib, test_track, 2, datetime.date.today())
        self.assertIsInstance(scanner.Queue.tasks[0], scanner.task.ImportTask)

    def test_scanner_update_library(self):
        lib = db.library.Table.find(test_album)
        scanner.update_library(lib)
        self.assertIsInstance(scanner.Queue.tasks[0],
                              scanner.task.CheckSchedulerTask)

    def test_scanner_remove_library(self):
        lib = db.library.Table.find(test_album)
        scanner.remove_library(lib)
        self.assertIsInstance(scanner.Queue.tasks[0],
                              scanner.task.RemoveLibrarySchedulerTask)

    def test_scanner_widgets(self):
        lib = db.library.Table.find(test_album)

        self.assertIsInstance(scanner.ProgressBar(),
                              scanner.widgets.ProgressBar)
        self.assertIsInstance(scanner.AddFolderButton(),
                              scanner.widgets.AddFolderButton)
        self.assertIsInstance(scanner.UpdateButton(lib),
                              scanner.widgets.UpdateButton)
        self.assertIsInstance(scanner.UpdateAllButton(),
                              scanner.widgets.UpdateAllButton)
        self.assertIsInstance(scanner.RemoveButton(lib),
                              scanner.widgets.RemoveButton)
