# Copyright 2021 (c) Anna Schumaker.
from lib import settings
from lib import version
from . import window
from . import header
from . import keyboard
from . import pane
from gi.repository import Gtk
import sidebar
import unittest

class TestUIWindow(unittest.TestCase):
    def tearDown(self):
        settings.reset()
        window.initialize()

    def setUpClass():
        settings.reset()
        window.initialize()

    def test_window_init(self):
        self.assertIsInstance(window.Window, Gtk.ApplicationWindow)
        self.assertIsInstance(window.Box, Gtk.Box)

        self.assertIn(sidebar.Switcher, window.Box)
        self.assertIn(pane.Pane, window.Box)

        self.assertEqual(window.Window.get_titlebar(), header.Header)
        self.assertEqual(window.Window.get_child(), window.Box)
        window.Window.present()

        self.assertEqual(window.Window.get_title(), version.string())
        self.assertEqual(window.Window.get_icon_name(), "emmental")

        self.assertEqual(keyboard.Event.get_widget(), window.Window)

    def test_window_resize(self):
        self.assertEqual(settings.get_int("window.width"), 1100)
        self.assertEqual(settings.get_int("window.height"), 600)

        self.assertEqual(window.Window.get_property("default-width"), 1100)
        self.assertEqual(window.Window.get_property("default-height"), 600)
        self.assertFalse(window.Window.is_maximized())

        window.Window.set_default_size(1200, 800)
        self.assertEqual(settings.get_int("window.width"), 1200)
        self.assertEqual(settings.get_int("window.height"), 800)

    def test_window_maximize(self):
        self.assertFalse(settings.get_bool("window.maximized"))
        (width, height) = window.Window.get_default_size()

        window.Window.maximize()
        #self.assertTrue(settings.get_bool("window.maximized"))
        self.assertEqual(settings.get_int("window.width"), width)
        self.assertEqual(settings.get_int("window.height"), height)

        window.Window.unmaximize()
        self.assertEqual(settings.get_int("window.width"), width)
        self.assertEqual(settings.get_int("window.height"), height)
        self.assertFalse(window.Window.is_maximized())
